from setuptools import setup

setup(
    name="toolsmaximum",  # Unique name on PyPI
    version="0.1.0",  # Follow semantic versioning
    description="The best tools in all of python (py discord to give recommendations at @!)",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",  # For markdown README
    author="Python-Best-Coder",
    author_email="mqrshymelio@gmail.com",
    url="https://github.com/Python-Best-Coder/toolsmax/blob/main/",
    packages=[],  # List of all Python importable packages
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.0",
)
